import { EventEmitter, Component, ChangeDetectorRef, ViewChild, Input, Output, NgModule } from '@angular/core';
import { fromEvent } from 'rxjs';
import { map, debounceTime, distinctUntilChanged } from 'rxjs/operators';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * Generated from: lib/search-input.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var SearchInputComponent = /** @class */ (function () {
    function SearchInputComponent(changeDetector) {
        this.changeDetector = changeDetector;
        this.config = {
            placeholderText: 'Search...',
            minSearchLength: 3,
            searchLengthError: 'Search term must be at least 3 characters',
            debounceTime: 500
        };
        this.searchInputChanged = new EventEmitter();
        this.smallSearchTermError = false;
    }
    /**
     * @return {?}
     */
    SearchInputComponent.prototype.ngAfterViewInit = /**
     * @return {?}
     */
    function () {
        this.listenForSearch();
    };
    /**
     * @return {?}
     */
    SearchInputComponent.prototype.ngOnDestroy = /**
     * @return {?}
     */
    function () {
        this.searchSubscription.unsubscribe();
    };
    /**
     * @return {?}
     */
    SearchInputComponent.prototype.listenForSearch = /**
     * @return {?}
     */
    function () {
        var _this = this;
        this.searchSubscription = fromEvent(this.txtSearchInput.nativeElement, 'keyup').pipe(
        // get value
        map((/**
         * @param {?} event
         * @return {?}
         */
        function (event) {
            return event.target.value;
        }))
        // Time in milliseconds between key events
        , debounceTime(this.config.debounceTime)
        // If previous query is diffent from current
        , distinctUntilChanged()
        // subscription for response
        ).subscribe((/**
         * @param {?} text
         * @return {?}
         */
        function (text) {
            if (text.length < _this.config.minSearchLength && text.length !== 0) {
                _this.smallSearchTermError = true;
            }
            else {
                _this.smallSearchTermError = false;
                _this.searchInputChanged.emit(text);
            }
        }));
    };
    SearchInputComponent.decorators = [
        { type: Component, args: [{
                    selector: 'ngc-search-input',
                    template: "<input type=\"text\" [placeholder]=\"config.placeholderText\" class=\"form-control\" #txtSearchInput />\r\n<div class=\"text-danger\" *ngIf=\"smallSearchTermError\">{{config.searchLengthError}}</div>"
                }] }
    ];
    /** @nocollapse */
    SearchInputComponent.ctorParameters = function () { return [
        { type: ChangeDetectorRef }
    ]; };
    SearchInputComponent.propDecorators = {
        txtSearchInput: [{ type: ViewChild, args: ['txtSearchInput', { static: false },] }],
        config: [{ type: Input }],
        searchInputChanged: [{ type: Output }]
    };
    return SearchInputComponent;
}());
if (false) {
    /** @type {?} */
    SearchInputComponent.prototype.txtSearchInput;
    /** @type {?} */
    SearchInputComponent.prototype.config;
    /** @type {?} */
    SearchInputComponent.prototype.searchInputChanged;
    /** @type {?} */
    SearchInputComponent.prototype.searchSubscription;
    /** @type {?} */
    SearchInputComponent.prototype.smallSearchTermError;
    /** @type {?} */
    SearchInputComponent.prototype.changeDetector;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/search-input.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var SearchInputModule = /** @class */ (function () {
    function SearchInputModule() {
    }
    SearchInputModule.decorators = [
        { type: NgModule, args: [{
                    imports: [CommonModule],
                    declarations: [SearchInputComponent],
                    exports: [SearchInputComponent]
                },] }
    ];
    return SearchInputModule;
}());

/**
 * @fileoverview added by tsickle
 * Generated from: public-api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: ngc-search-input.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { SearchInputComponent, SearchInputModule };
//# sourceMappingURL=ngc-search-input.js.map
